flutter_watch_rewards library

Classes

WatchRewards
A customizable Flutter widget that displays a circular progress indicator with rewards functionality.
WatchRewardsController
Controller for manually managing the state of a WatchRewards widget.