WatchRewardsController class

Controller for manually managing the state of a WatchRewards widget.

This controller allows external control over starting, stopping, and pausing the progress of a WatchRewards widget.

Constructors

WatchRewardsController()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pause() → void
Pauses the progress of the associated WatchRewards widget.
start() → void
Starts the progress of the associated WatchRewards widget.
stop() → void
Stops the progress of the associated WatchRewards widget and resets the count.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited